@@ -327,7 +327,6 @@ class Root(State):
         self,
         owner=None,
         initial_value=Slot.NOT_KNOWN,
-        initial_position=None,
     ):
         """
         Creates a new :py:class:`Slot` in this root.
@@ -335,7 +334,7 @@ class Root(State):
         The slot's value will remain mutable for the lifetime of the root
         context, and will be frozen upon its exit.
         """
-        slot = self.slot_type(self, owner, initial_value, initial_position)
+        slot = self.slot_type(self, owner, initial_value)
         self.slots.add(slot)
         return slot
 
@@ -353,8 +352,8 @@ class Root(State):
 
     def finalize_data(self):
         for slot in self.slots:
-            slot.final_value = slot.value
-            slot.final_position = slot.position
+            slot.final_value = self.get_slot_value(slot)
+            slot.final_positions = self.get_slot_positions(slot)
             # sever the connection from the slot to the root so that
             # the root can be garbage collected after the with block exits.
             # The slot doesn't need the root anymore.
@@ -434,6 +433,12 @@ class MergeConflictPossibility(object):
                 'Cannot compare MergeConflictPossibility to %r' % type(other)
             )
 
+    def __cmp__(self, other):
+        return cmp(
+            (self.value, list(sorted(self.positions))),
+            (other.value, list(sorted(other.positions))),
+        )
+
 
 class ValueNotKnownError(Exception):
     """
